Learn R Programming

ineqJD (version 1.0)

zenga: Point and synthetic Zenga 2007 indexes

Description

Computes point and synthetic Zenga 2007 indexes on a variable \(Y\).

Usage

zenga(x)

Arguments

x

List containing: 'yh', the vector of unique values of the variable \(Y\) whose Bonferroni index is computed; 'Phl', the matrix of absoute cumulative frequencies; 'Qhlk', the matrix of cumlative sums of y or its sources. x is usually the result of dataProcessing function. More details are given in the "Details" section and dataProcessing help page.

Value

index

String denoting computed index.

decomposition

Array containing the decompositions.

x

Object usually of class dataProcessed passed as input.

Details

zenga compute point and synthetic Zenga 2007 indexes on a variable y, e.g. income, on a statistical population that could be partitioned in g subpopultions and could be considered as sum of c sources, e.g. income sources.

References

Zenga M. M.(2007). Inequality Curve and Inequality Index based on the Ratios between lower and upper means . Statistica and Applicazioni, V (1), 3-27.

Zenga M. (2015) Joint decomposition by subpopulations and sources of the point and synthetic Zenga(2007) Index I(Y). Statistica and Applicazioni, XIII (2), pp.163-195.

Examples

Run this code
# NOT RUN {
G <- c(1, 2, 3, 1, 2, 3, 1, 1, 2, 3, 3, 3) # vector denoting group membership
X1 <- c(0, 0, 0, 500, 700, 300, 750, 1000, 500, 500, 500, 1000) # vector of the first source
X2 <- c(0, 0, 0, 500, 300, 700, 750, 500, 700, 700, 1000,600) # vector of the second source
data <- data.frame(G, X1, X2) # no sample weights are considered
x <- dataProcessing( # data preparation
  units = data[, c('X1', 'X2')],
  groups = data[, 'G'],
)
  
decomposition <- zenga(x)
decomposition
# }

Run the code above in your browser using DataLab